@@ -5,9 +5,8 @@ use utf8;
 
 package Neo4j::Driver::Record;
 # ABSTRACT: Container for Cypher result values
-$Neo4j::Driver::Record::VERSION = '0.12_02'; # TRIAL
+$Neo4j::Driver::Record::VERSION = '0.09';
 
-$Neo4j::Driver::Record::VERSION = '0.1202';
 use Carp qw(carp croak);
 use JSON::PP;
 
@@ -87,7 +86,7 @@ Neo4j::Driver::Record - Container for Cypher result values
 
 =head1 VERSION
 
-version 0.12_02
+version 0.09
 
 =head1 SYNOPSIS
 
@@ -102,7 +101,7 @@ version 0.12_02
  
  $query .= ' ORDER BY m.year LIMIT 1';
  my $record = $session->run($query)->single;
- say 'Year of oldest movie: ', $record->get(1);
+ say 'Age of oldest movie: ', $record->get(1);
 
 =head1 DESCRIPTION
 
@@ -188,7 +187,7 @@ Arne Johannessen <ajnn@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016-2019 by Arne Johannessen.
+This software is Copyright (c) 2016-2018 by Arne Johannessen.
 
 This is free software, licensed under:
 
