@@ -5,9 +5,8 @@ use utf8;
 
 package Neo4j::Driver::ResultSummary;
 # ABSTRACT: Details about the result of running a statement
-$Neo4j::Driver::ResultSummary::VERSION = '0.12_02'; # TRIAL
+$Neo4j::Driver::ResultSummary::VERSION = '0.09';
 
-$Neo4j::Driver::ResultSummary::VERSION = '0.1202';
 use Carp qw(croak);
 
 use Neo4j::Driver::SummaryCounters;
@@ -94,14 +93,16 @@ Neo4j::Driver::ResultSummary - Details about the result of running a statement
 
 =head1 VERSION
 
-version 0.12_02
+version 0.09
 
 =head1 SYNOPSIS
 
  use Neo4j::Driver;
  my $driver = Neo4j::Driver->new->basic_auth(...);
- my $result = $driver->session->run('MATCH (a)-[:KNOWS]-(b) RETURN a, b');
  
+ my $transaction = $driver->session->begin_transaction;
+ $transaction->{return_stats} = 1;
+ my $result = $transaction->run('MATCH (a)-[:KNOWS]-(b) RETURN a, b');
  my $summary = $result->summary;
  
  # SummaryCounters
@@ -190,7 +191,7 @@ Arne Johannessen <ajnn@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016-2019 by Arne Johannessen.
+This software is Copyright (c) 2016-2018 by Arne Johannessen.
 
 This is free software, licensed under:
 
