@@ -5,22 +5,26 @@ use utf8;
 
 package Neo4j::Driver::Session;
 # ABSTRACT: Context of work for database interactions
-$Neo4j::Driver::Session::VERSION = '0.12_02'; # TRIAL
+$Neo4j::Driver::Session::VERSION = '0.09';
 
-$Neo4j::Driver::Session::VERSION = '0.1202';
 use Cpanel::JSON::XS 3.0201 qw(decode_json);
 use URI 1.25;
 
 use Neo4j::Driver::Transaction;
 
 
+# https://neo4j.com/docs/rest-docs/current/#rest-api-service-root
+our $SERVICE_ROOT_ENDPOINT = '/db/data/';
+
+
 sub new {
-	my ($class, $transport) = @_;
+	my ($class, $driver) = @_;
 	
 	my $session = {
 #		driver => $driver,
 #		uri => $driver->{uri}->clone,
-		transport => $transport,
+		client => $driver->_client,
+		die_on_error => $driver->{die_on_error},
 	};
 	
 	return bless $session, $class;
@@ -30,16 +34,15 @@ sub new {
 sub begin_transaction {
 	my ($self) = @_;
 	
-	my $t = Neo4j::Driver::Transaction->new($self);
-	return $t->_explicit;
+	return Neo4j::Driver::Transaction->new($self);
 }
 
 
 sub run {
 	my ($self, $query, @parameters) = @_;
 	
-	my $t = Neo4j::Driver::Transaction->new($self);
-	return $t->_autocommit->run($query, @parameters);
+	my $t = $self->begin_transaction();
+	return $t->_commit($query, @parameters);
 }
 
 
@@ -50,7 +53,27 @@ sub close {
 sub server {
 	my ($self) = @_;
 	
-	return $self->{transport}->server_info;
+	# That the ServerInfo is provided by the same object as Session
+	# is an implementation detail that might change in future.
+	return $self;
+}
+
+
+# server->
+sub address {
+	my ($self) = @_;
+	
+	return URI->new( $self->{client}->getHost() )->host_port;
+}
+
+
+# server->
+sub version {
+	my ($self) = @_;
+	
+	my $json = $self->{client}->GET( $SERVICE_ROOT_ENDPOINT )->responseContent();
+	my $neo4j_version = decode_json($json)->{neo4j_version};
+	return "Neo4j/$neo4j_version";
 }
 
 
@@ -68,7 +91,7 @@ Neo4j::Driver::Session - Context of work for database interactions
 
 =head1 VERSION
 
-version 0.12_02
+version 0.09
 
 =head1 SYNOPSIS
 
@@ -97,10 +120,6 @@ I<Explicit transactions> allow multiple statements to be committed
 as part of a single atomic operation and can be rolled back if
 necessary.
 
-Only one open transaction per session at a time is supported. To
-work with multiple concurrent transactions (also known as "nested
-transactions"), simply use more than one session.
-
 =head1 METHODS
 
 L<Neo4j::Driver::Session> implements the following methods.
@@ -143,17 +162,13 @@ context.
 
 =head2 Close method
 
- $session->close;  # no-op
-
-This driver does not support persistent connections at present. All
-connections are closed automatically. There is no need for explicit
-calls to C<close> at this time.
+C<close> is currently a no-op in this class.
 
 =head2 ServerInfo
 
  my $host_port = $session->server->address;
  my $version_string = $session->server->version;
- say "Contacting $version_string at $host_port.";
+ say "Result from $version_string at $host_port.";
 
 For security reasons, L<ResultSummary|Neo4j::Driver::ResultSummary>
 cannot provide C<ServerInfo>. Therefore, C<ServerInfo> is available
@@ -165,30 +180,6 @@ offer the C<ServerInfo> strings through
 L<ResultSummary|Neo4j::Driver::ResultSummary> after all. However,
 I'm really not sure if the ensuing performance penalty is worth it.
 
-=head2 Concurrent explicit transactions
-
- my $session = Neo4j::Driver->new('http://...')->basic_auth(...)->session;
- my $tx1 = $session->begin_transaction;
- my $tx2 = $session->begin_transaction;
-
-Since HTTP is a stateless protocol, the Neo4j HTTP API effectively
-allows multiple concurrently open transactions without special
-client-side considerations. This driver exposes this feature to the
-client and will continue to do so, but the interface is not yet
-finalised.
-
-The Bolt protocol does not support concurrent explicit transactions.
-
-=head2 Concurrent autocommit transactions
-
- my $tx1 = $session->begin_transaction;
- my $tx2 = $session->run(...);
-
-Sessions support autocommit transactions while an explicit
-transaction is open. Since it is not clear to me if this is
-intended behaviour when the Bolt protocol is used, this feature
-is listed as experimental.
-
 =head1 BUGS
 
 The implementation of sessions in this driver is incomplete. In
@@ -224,7 +215,7 @@ Arne Johannessen <ajnn@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016-2019 by Arne Johannessen.
+This software is Copyright (c) 2016-2018 by Arne Johannessen.
 
 This is free software, licensed under:
 
