@@ -5,9 +5,8 @@ use utf8;
 
 package Neo4j::Driver::StatementResult;
 # ABSTRACT: Result of running a Cypher statement (a list of records)
-$Neo4j::Driver::StatementResult::VERSION = '0.12_02'; # TRIAL
+$Neo4j::Driver::StatementResult::VERSION = '0.09';
 
-$Neo4j::Driver::StatementResult::VERSION = '0.1202';
 use Carp qw(carp croak);
 
 use Neo4j::Driver::Record;
@@ -110,7 +109,7 @@ Neo4j::Driver::StatementResult - Result of running a Cypher statement (a list of
 
 =head1 VERSION
 
-version 0.12_02
+version 0.09
 
 =head1 SYNOPSIS
 
@@ -167,6 +166,13 @@ Return the count of records in the result.
 
 Return a L<Neo4j::Driver::ResultSummary> object.
 
+The C<summary> method will fail unless the transaction has been
+modified to request statistics before the statement was run.
+
+ my $transaction = $session->begin_transaction;
+ $transaction->{return_stats} = 1;
+ my $result = $transaction->run('...');
+
 As a special case, L<Record|Neo4j::Driver::Record>s returned by the
 C<single> method also have a C<summary> method that works the same
 way.
@@ -204,7 +210,7 @@ Arne Johannessen <ajnn@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016-2019 by Arne Johannessen.
+This software is Copyright (c) 2016-2018 by Arne Johannessen.
 
 This is free software, licensed under:
 
