@@ -5,9 +5,8 @@ use utf8;
 
 package Neo4j::Driver::SummaryCounters;
 # ABSTRACT: Statement statistics
-$Neo4j::Driver::SummaryCounters::VERSION = '0.12_02'; # TRIAL
+$Neo4j::Driver::SummaryCounters::VERSION = '0.09';
 
-$Neo4j::Driver::SummaryCounters::VERSION = '0.1202';
 sub new {
 	my ($class, $stats) = @_;
 	
@@ -18,6 +17,7 @@ sub new {
 my @counters = qw(
 	constraints_added
 	constraints_removed
+	contains_updates
 	indexes_added
 	indexes_removed
 	labels_added
@@ -34,17 +34,6 @@ for my $c (@counters) { *$c = sub { shift->{$c} } }
 # see <https://github.com/neo4j/neo4j/issues/3421>
 sub relationships_deleted { shift->{relationship_deleted}; }
 
-# contains_updates is only present in the HTTP response;
-# we need to synthesize it from Bolt responses
-sub contains_updates {
-	my $self = shift;
-	unless (defined $self->{contains_updates}) {
-		$self->{contains_updates} = $self->{relationship_deleted} // 0;
-		$self->{contains_updates} += grep {$self->{$_}} @counters;
-	}
-	return !! $self->{contains_updates};
-}
-
 
 
 
@@ -62,7 +51,7 @@ Neo4j::Driver::SummaryCounters - Statement statistics
 
 =head1 VERSION
 
-version 0.12_02
+version 0.09
 
 =head1 SYNOPSIS
 
@@ -109,7 +98,7 @@ another, certain error conditions produce misleading statistics: It
 was observed that deleting a node that has relationships fails in a
 Cypher shell with an obscure error message, while it succeeds when
 executed over HTTP with this driver. However, the HTTP response then
-reports that the node was deleted, but that the relationship wasn't, which
+reports that the node was deleted, but the relationship wasn't, which
 is obviously inconsistent. Not quite sure what is going on there. To
 verify that modifying the database was successful, it would therefore
 probably make more sense to run a MATCH query, tedious or not.
@@ -125,7 +114,7 @@ Arne Johannessen <ajnn@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016-2019 by Arne Johannessen.
+This software is Copyright (c) 2016-2018 by Arne Johannessen.
 
 This is free software, licensed under:
 
