@@ -2,21 +2,16 @@ package Neo4j::Test;
 use strict;
 use warnings;
 
-use URI;
 use Neo4j::Driver;
-use Neo4j::Sim;
 
 my $ok;
 
 
-# may be used for conditional testing
-our $bolt;
-our $sim;
-
-
 # returns a driver that might or might not work
 sub driver_maybe {
 	
+	return unless my $pass = $ENV{TEST_NEO4J_PASSWORD};
+	
 	my $driver;
 	eval {
 		# a default URI (localhost) is built into the driver
@@ -25,7 +20,6 @@ sub driver_maybe {
 	return unless $driver;
 	
 	my $user = $ENV{TEST_NEO4J_USERNAME} || 'neo4j';
-	my $pass = $ENV{TEST_NEO4J_PASSWORD};
 	$driver->basic_auth($user, $pass);
 	
 	return $driver;
@@ -36,14 +30,6 @@ sub driver_maybe {
 sub driver {
 	my $driver = driver_maybe;
 	
-	$bolt = $driver->{uri} && $driver->{uri}->scheme eq 'bolt';
-	if (! $ENV{TEST_NEO4J_PASSWORD} && $driver && ! $bolt) {
-		# the driver has no chance of connecting to a real database via
-		# HTTP without a password, so we use the REST simulator instead
-		$driver->{client_factory} = Neo4j::Sim->factory;
-		$sim = 1;
-	}
-	
 	# verify that the supplied credentials actually work
 	eval {
 		# the Neo4j HTTP API allows running empty statements
@@ -60,11 +46,8 @@ sub driver {
 sub driver_ok { $ok }
 
 
-# used for the ResultSummary/ServerInfo test
-sub server_address {
-	return 'localhost:7474' unless $ENV{TEST_NEO4J_SERVER};
-	return '' . URI->new( $ENV{TEST_NEO4J_SERVER} )->host_port;
-}
+# used for the ResultSummary test
+sub server_address { $ENV{TEST_NEO4J_SERVER} || 'localhost:7474' }
 
 
 1;
